@@ -1,20 +1,23 @@
 # rasterio
 
+from collections import namedtuple
 import logging
 import os
 
+import numpy
+
 from rasterio.five import string_types
 from rasterio._copy import RasterCopier
 from rasterio._io import RasterReader, RasterUpdater
 from rasterio._io import eval_window, window_index, window_shape
-from rasterio._drivers import DriverManager, DummyManager, driver_count
+from rasterio._drivers import driver_count, GDALEnv
 import rasterio.dtypes
 from rasterio.dtypes import (
     bool_, ubyte, uint8, uint16, int16, uint32, int32, float32, float64)
 
 
 __all__ = ['open', 'drivers', 'copy', 'check_dtype']
-__version__ = "0.6"
+__version__ = "0.7.1"
 
 log = logging.getLogger('rasterio')
 class NullHandler(logging.Handler):
@@ -22,6 +25,14 @@ class NullHandler(logging.Handler):
         pass
 log.addHandler(NullHandler())
 
+def band(ds, bidx):
+    """Wraps a dataset and a band index up as a 'Band'"""
+    Band = namedtuple('Band', ['ds', 'bidx', 'dtype', 'shape'])
+    return Band(
+        ds, 
+        bidx, 
+        numpy.dtype(set(ds.dtypes).pop()),
+        ds.shape)
 
 def open(
         path, mode='r', 
@@ -85,8 +96,7 @@ def open(
     if mode == 'r':
         s = RasterReader(path)
     elif mode == 'r+':
-        raise NotImplemented("r+ mode not implemented")
-        # s = RasterUpdater(path, mode, driver=None)
+        s = RasterUpdater(path, mode)
     elif mode == 'w':
         s = RasterUpdater(
                 path, mode, driver,
@@ -119,12 +129,12 @@ def copy(src, dst, **kw):
     with drivers():
         return RasterCopier()(src, dst, **kw)
 
-def drivers(*args):
-    """Returns a context manager with registered drivers."""
+def drivers(**kwargs):
+    """Returns a gdal environment with registered drivers."""
     if driver_count() == 0:
-        log.debug("Creating a DriverManager in drivers()")
-        return DriverManager()
+        log.debug("Creating a chief GDALEnv in drivers()")
+        return GDALEnv(True, **kwargs)
     else:
-        log.debug("Creating a DummyManager in drivers()")
-        return DummyManager()
+        log.debug("Creating a not-responsible GDALEnv in drivers()")
+        return GDALEnv(False, **kwargs)
 
