@@ -23,6 +23,23 @@ dtype_fwd = {
     6: float32,     # GDT_Float32
     7: float64 }   # GDT_Float64
 
-dtype_rev = {v: k for k, v in dtype_fwd.items()}
+dtype_rev = dict((v, k) for k, v in dtype_fwd.items())
 dtype_rev[uint8] = 1
 
+typename_fwd = {
+    0: 'Unknown',
+    1: 'Byte',
+    2: 'UInt16',
+    3: 'Int16',
+    4: 'UInt32',
+    5: 'Int32',
+    6: 'Float32',
+    7: 'Float64' }
+
+typename_rev = dict((v, k) for k, v in typename_fwd.items())
+
+def _gdal_typename(dtype):
+    return typename_fwd[dtype_rev[dtype]]
+
+
+
